<?php

namespace B2buy\Shipping\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Shipping\Http\Requests\RegionRequest;
use B2buy\Shipping\Interfaces\RegionRepositoryInterface;
use B2buy\Shipping\Models\Region;
use B2buy\Shipping\Forms\Region as Form;

/**
 * APIController  class for region.
 */
class RegionAPIController extends BaseController
{

    /**
     * Initialize region resource controller.
     *
     * @param type RegionRepositoryInterface $region
     *
     * @return null
     */
    public function __construct(RegionRepositoryInterface $region)
    {
        parent::__construct();
        $this->repository = $region;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Shipping\Repositories\Criteria\RegionResourceCriteria::class);
    }

    /**
     * Display a list of region.
     *
     * @return Response
     */
    public function index(RegionRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Shipping\Repositories\Presenter\RegionPresenter::class)
            ->paginate();
    }

    /**
     * Display region.
     *
     * @param Request $request
     * @param Model   $region
     *
     * @return Response
     */
    public function show(RegionRequest $request, Region $region)
    {
        return $region->setPresenter(\B2buy\Shipping\Repositories\Presenter\RegionListPresenter::class);
        ;
    }

    /**
     * Create new region.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RegionRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('shipping::region.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('shipping/region/' . $region->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('shipping/region');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the region.
     *
     * @param Request $request
     * @param Model   $region
     *
     * @return Response
     */
    public function update(RegionRequest $request, Region $region)
    {
        try {
            $data = $request->all();

            $region->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('shipping::region.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('shipping/region/' . $region->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('shipping/region/' . $region->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the region.
     *
     * @param Model   $region
     *
     * @return Response
     */
    public function destroy(RegionRequest $request, Region $region)
    {
        try {
            $region->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('shipping::region.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('shipping/region/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('shipping/region/' . $region->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
