<?php

namespace B2buy\Shipping\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Shipping\Http\Requests\RegionAreaRequest;
use B2buy\Shipping\Models\RegionArea;

/**
 * Admin web controller class.
 */
class RegionAreaWorkflowController extends BaseController
{

    /**
     * Workflow controller function for region_area.
     *
     * @param Model   $region_area
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(RegionAreaRequest $request, RegionArea $region_area, $step)
    {

        try {

            $region_area->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('shipping::region_area.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/region_area/region_area/' . $region_area->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/region_area/region_area/' . $region_area->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for region_area.
     *
     * @param Model   $region_area
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(RegionArea $region_area, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $region_area->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('shipping::region_area.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.region_area.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.region_area.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.region_area.message', $data)->render();

        }

    }
}
