<?php

namespace B2buy\Shipping\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Shipping\Http\Requests\RegionRequest;
use B2buy\Shipping\Models\Region;

/**
 * Admin web controller class.
 */
class RegionWorkflowController extends BaseController
{

    /**
     * Workflow controller function for region.
     *
     * @param Model   $region
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(RegionRequest $request, Region $region, $step)
    {

        try {

            $region->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('shipping::region.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/region/region/' . $region->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/region/region/' . $region->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for region.
     *
     * @param Model   $region
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Region $region, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $region->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('shipping::region.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.region.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.region.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.region.message', $data)->render();

        }

    }
}
