<?php

namespace B2buy\Shipping\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Shipping\Http\Requests\ShippingRequest;
use B2buy\Shipping\Models\Shipping;

/**
 * Admin web controller class.
 */
class ShippingWorkflowController extends BaseController
{

    /**
     * Workflow controller function for shipping.
     *
     * @param Model   $shipping
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ShippingRequest $request, Shipping $shipping, $step)
    {

        try {

            $shipping->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('shipping::shipping.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/shipping/shipping/' . $shipping->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/shipping/shipping/' . $shipping->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for shipping.
     *
     * @param Model   $shipping
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Shipping $shipping, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $shipping->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('shipping::shipping.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.shipping.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.shipping.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('shipping::admin.shipping.message', $data)->render();

        }

    }
}
