<?php

namespace B2buy\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Shipping\Models\RegionArea;

class RegionAreaPolicy
{

    /**
     * Determine if the given user can view the region_area.
     *
     * @param UserPolicy $user
     * @param RegionArea $region_area
     *
     * @return bool
     */
    public function view(UserPolicy $user, RegionArea $region_area)
    {
        if ($user->canDo('shipping.region_area.view') && $user->isAdmin()) {
            return true;
        }

        return $region_area->user_id == user_id() && $region_area->user_type == user_type();
    }

    /**
     * Determine if the given user can create a region_area.
     *
     * @param UserPolicy $user
     * @param RegionArea $region_area
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.region_area.create');
    }

    /**
     * Determine if the given user can update the given region_area.
     *
     * @param UserPolicy $user
     * @param RegionArea $region_area
     *
     * @return bool
     */
    public function update(UserPolicy $user, RegionArea $region_area)
    {
        if ($user->canDo('shipping.region_area.edit') && $user->isAdmin()) {
            return true;
        }

        return $region_area->user_id == user_id() && $region_area->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given region_area.
     *
     * @param UserPolicy $user
     * @param RegionArea $region_area
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RegionArea $region_area)
    {
        return $region_area->user_id == user_id() && $region_area->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given region_area.
     *
     * @param UserPolicy $user
     * @param RegionArea $region_area
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RegionArea $region_area)
    {
        if ($user->canDo('shipping.region_area.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given region_area.
     *
     * @param UserPolicy $user
     * @param RegionArea $region_area
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RegionArea $region_area)
    {
        if ($user->canDo('shipping.region_area.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
