<?php

namespace B2buy\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Shipping\Models\Region;

class RegionPolicy
{

    /**
     * Determine if the given user can view the region.
     *
     * @param UserPolicy $user
     * @param Region $region
     *
     * @return bool
     */
    public function view(UserPolicy $user, Region $region)
    {
        if ($user->canDo('shipping.region.view') && $user->isAdmin()) {
            return true;
        }

        return $region->user_id == user_id() && $region->user_type == user_type();
    }

    /**
     * Determine if the given user can create a region.
     *
     * @param UserPolicy $user
     * @param Region $region
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.region.create');
    }

    /**
     * Determine if the given user can update the given region.
     *
     * @param UserPolicy $user
     * @param Region $region
     *
     * @return bool
     */
    public function update(UserPolicy $user, Region $region)
    {
        if ($user->canDo('shipping.region.edit') && $user->isAdmin()) {
            return true;
        }

        return $region->user_id == user_id() && $region->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given region.
     *
     * @param UserPolicy $user
     * @param Region $region
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Region $region)
    {
        return $region->user_id == user_id() && $region->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given region.
     *
     * @param UserPolicy $user
     * @param Region $region
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Region $region)
    {
        if ($user->canDo('shipping.region.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given region.
     *
     * @param UserPolicy $user
     * @param Region $region
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Region $region)
    {
        if ($user->canDo('shipping.region.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
