<?php

namespace B2buy\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Shipping\Models\RegionSurcharge;

class RegionSurchargePolicy
{

    /**
     * Determine if the given user can view the region_surcharge.
     *
     * @param UserPolicy $user
     * @param RegionSurcharge $region_surcharge
     *
     * @return bool
     */
    public function view(UserPolicy $user, RegionSurcharge $region_surcharge)
    {
        if ($user->canDo('shipping.region_surcharge.view') && $user->isAdmin()) {
            return true;
        }

        return $region_surcharge->user_id == user_id() && $region_surcharge->user_type == user_type();
    }

    /**
     * Determine if the given user can create a region_surcharge.
     *
     * @param UserPolicy $user
     * @param RegionSurcharge $region_surcharge
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.region_surcharge.create');
    }

    /**
     * Determine if the given user can update the given region_surcharge.
     *
     * @param UserPolicy $user
     * @param RegionSurcharge $region_surcharge
     *
     * @return bool
     */
    public function update(UserPolicy $user, RegionSurcharge $region_surcharge)
    {
        if ($user->canDo('shipping.region_surcharge.edit') && $user->isAdmin()) {
            return true;
        }

        return $region_surcharge->user_id == user_id() && $region_surcharge->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given region_surcharge.
     *
     * @param UserPolicy $user
     * @param RegionSurcharge $region_surcharge
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RegionSurcharge $region_surcharge)
    {
        return $region_surcharge->user_id == user_id() && $region_surcharge->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given region_surcharge.
     *
     * @param UserPolicy $user
     * @param RegionSurcharge $region_surcharge
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RegionSurcharge $region_surcharge)
    {
        if ($user->canDo('shipping.region_surcharge.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given region_surcharge.
     *
     * @param UserPolicy $user
     * @param RegionSurcharge $region_surcharge
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RegionSurcharge $region_surcharge)
    {
        if ($user->canDo('shipping.region_surcharge.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
