<?php

namespace B2buy\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Shipping\Models\Shipping;

class ShippingPolicy
{

    /**
     * Determine if the given user can view the shipping.
     *
     * @param UserPolicy $user
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function view(UserPolicy $user, Shipping $shipping)
    {
        if ($user->canDo('shipping.shipping.view') && $user->isAdmin()) {
            return true;
        }

        return $shipping->user_id == user_id() && $shipping->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shipping.
     *
     * @param UserPolicy $user
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.shipping.create');
    }

    /**
     * Determine if the given user can update the given shipping.
     *
     * @param UserPolicy $user
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function update(UserPolicy $user, Shipping $shipping)
    {
        if ($user->canDo('shipping.shipping.edit') && $user->isAdmin()) {
            return true;
        }

        return $shipping->user_id == user_id() && $shipping->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shipping.
     *
     * @param UserPolicy $user
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Shipping $shipping)
    {
        return $shipping->user_id == user_id() && $shipping->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shipping.
     *
     * @param UserPolicy $user
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Shipping $shipping)
    {
        if ($user->canDo('shipping.shipping.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shipping.
     *
     * @param UserPolicy $user
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Shipping $shipping)
    {
        if ($user->canDo('shipping.shipping.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
