<?php

namespace B2buy\Shipping\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use B2buy\Shipping\Models\Shipping;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'B2buy\Shipping\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/shipping/region/*')) {
            Route::bind('region', function ($region) {
                $regionrepo = $this->app->make('B2buy\Shipping\Interfaces\RegionRepositoryInterface');
                return $regionrepo->findorNew($region);
            });
        }

        if (Request::is('*/shipping/region_area/*')) {
            Route::bind('region_area', function ($region_area) {
                $region_arearepo = $this->app->make('B2buy\Shipping\Interfaces\RegionAreaRepositoryInterface');
                return $region_arearepo->findorNew($region_area);
            });
        }

        if (Request::is('*/shipping/shipping/*')) {
            Route::bind('shipping', function ($shipping) {
                $shippingrepo = $this->app->make('B2buy\Shipping\Interfaces\ShippingRepositoryInterface');
                return $shippingrepo->findorNew($shipping);
            });
        }

        if (Request::is('*/shipping/region_surcharge/*')) {
            Route::bind('region_surcharge', function ($region_surcharge) {
                $region_surchargerepo = $this->app->make('B2buy\Shipping\Interfaces\RegionSurchargeRepositoryInterface');
                return $region_surchargerepo->findorNew($region_surcharge);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
