<?php

namespace B2buy\Shipping\Providers;

use Illuminate\Support\ServiceProvider;

class ShippingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'shipping');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'shipping');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerShipping();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerShipping()
    {
        $this->app->bind('shipping', function($app) {
            return new Shipping($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Shipping', 'Lavalite\Shipping\Facades\Shipping');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('b2buy.shipping', function ($app) {
            return $this->app->make('B2buy\Shipping\Shipping');
        });

        // Bind Region to repository
        $this->app->bind(
            'B2buy\Shipping\Interfaces\RegionRepositoryInterface',
            \B2buy\Shipping\Repositories\Eloquent\RegionRepository::class
        );
        // Bind RegionArea to repository
        $this->app->bind(
            'B2buy\Shipping\Interfaces\RegionAreaRepositoryInterface',
            \B2buy\Shipping\Repositories\Eloquent\RegionAreaRepository::class
        );
        // Bind Shipping to repository
        $this->app->bind(
            'B2buy\Shipping\Interfaces\ShippingRepositoryInterface',
            \B2buy\Shipping\Repositories\Eloquent\ShippingRepository::class
        );
        // Bind RegionSurcharge to repository
        $this->app->bind(
            'B2buy\Shipping\Interfaces\RegionSurchargeRepositoryInterface',
            \B2buy\Shipping\Repositories\Eloquent\RegionSurchargeRepository::class
        );

        $this->app->register(\B2buy\Shipping\Providers\AuthServiceProvider::class);
                $this->app->register(\B2buy\Shipping\Providers\EventServiceProvider::class);
        
        $this->app->register(\B2buy\Shipping\Providers\RouteServiceProvider::class);
                // $this->app->register(\B2buy\Shipping\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and shipping's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'b2buy.shipping'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeShipping::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['b2buy.shipping'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('b2buy/shipping.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/shipping')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/shipping')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
