<?php

namespace B2buy\Shipping\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Region workflow validator
        'B2buy\Shipping\Models\Region' => \B2buy\Shipping\Workflow\RegionValidator::class,

        // Bind RegionArea workflow validator
        'B2buy\Shipping\Models\RegionArea' => \B2buy\Shipping\Workflow\RegionAreaValidator::class,

        // Bind Shipping workflow validator
        'B2buy\Shipping\Models\Shipping' => \B2buy\Shipping\Workflow\ShippingValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Region workflow actions
        'B2buy\Shipping\Models\Region' => \B2buy\Shipping\Workflow\RegionAction::class,

        // Bind RegionArea workflow actions
        'B2buy\Shipping\Models\RegionArea' => \B2buy\Shipping\Workflow\RegionAreaAction::class,

        // Bind Shipping workflow actions
        'B2buy\Shipping\Models\Shipping' => \B2buy\Shipping\Workflow\ShippingAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Region workflow notifiers
        'B2buy\Shipping\Models\Region' => \B2buy\Shipping\Workflow\RegionNotifier::class,

        // Bind RegionArea workflow notifiers
        'B2buy\Shipping\Models\RegionArea' => \B2buy\Shipping\Workflow\RegionAreaNotifier::class,

        // Bind Shipping workflow notifiers
        'B2buy\Shipping\Models\Shipping' => \B2buy\Shipping\Workflow\ShippingNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
