<?php

namespace B2buy\Shipping\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Shipping\Models\Region;

class RegionAction
{
    /**
     * Perform the complete action.
     *
     * @param Region $region
     *
     * @return Region
     */
    public function complete(Region $region)
    {
        try {
            $region->status = 'complete';
            return $region->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Region $region
     *
     * @return Region
     */public function verify(Region $region)
    {
        try {
            $region->status = 'verify';
            return $region->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Region $region
     *
     * @return Region
     */public function approve(Region $region)
    {
        try {
            $region->status = 'approve';
            return $region->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Region $region
     *
     * @return Region
     */public function publish(Region $region)
    {
        try {
            $region->status = 'publish';
            return $region->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Region $region
     *
     * @return Region
     */
    public function archive(Region $region)
    {
        try {
            $region->status = 'archive';
            return $region->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Region $region
     *
     * @return Region
     */
    public function unpublish(Region $region)
    {
        try {
            $region->status = 'unpublish';
            return $region->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
