<?php

namespace B2buy\Shipping\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Shipping\Models\RegionArea;

class RegionAreaAction
{
    /**
     * Perform the complete action.
     *
     * @param RegionArea $region_area
     *
     * @return RegionArea
     */
    public function complete(RegionArea $region_area)
    {
        try {
            $region_area->status = 'complete';
            return $region_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param RegionArea $region_area
     *
     * @return RegionArea
     */public function verify(RegionArea $region_area)
    {
        try {
            $region_area->status = 'verify';
            return $region_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param RegionArea $region_area
     *
     * @return RegionArea
     */public function approve(RegionArea $region_area)
    {
        try {
            $region_area->status = 'approve';
            return $region_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param RegionArea $region_area
     *
     * @return RegionArea
     */public function publish(RegionArea $region_area)
    {
        try {
            $region_area->status = 'publish';
            return $region_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param RegionArea $region_area
     *
     * @return RegionArea
     */
    public function archive(RegionArea $region_area)
    {
        try {
            $region_area->status = 'archive';
            return $region_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param RegionArea $region_area
     *
     * @return RegionArea
     */
    public function unpublish(RegionArea $region_area)
    {
        try {
            $region_area->status = 'unpublish';
            return $region_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
