<?php

namespace B2buy\Shipping\Workflow;

use B2buy\Shipping\Models\RegionArea;
use Validator;

class RegionAreaValidator
{

    /**
     * Determine if the given region_area is valid for complete status.
     *
     * @param RegionArea $region_area
     *
     * @return bool / Validator
     */
    public function complete(RegionArea $region_area)
    {
        return Validator::make($region_area->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given region_area is valid for verify status.
     *
     * @param RegionArea $region_area
     *
     * @return bool / Validator
     */
    public function verify(RegionArea $region_area)
    {
        return Validator::make($region_area->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given region_area is valid for approve status.
     *
     * @param RegionArea $region_area
     *
     * @return bool / Validator
     */
    public function approve(RegionArea $region_area)
    {
        return Validator::make($region_area->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given region_area is valid for publish status.
     *
     * @param RegionArea $region_area
     *
     * @return bool / Validator
     */
    public function publish(RegionArea $region_area)
    {
        return Validator::make($region_area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given region_area is valid for archive status.
     *
     * @param RegionArea $region_area
     *
     * @return bool / Validator
     */
    public function archive(RegionArea $region_area)
    {
        return Validator::make($region_area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given region_area is valid for unpublish status.
     *
     * @param RegionArea $region_area
     *
     * @return bool / Validator
     */
    public function unpublish(RegionArea $region_area)
    {
        return Validator::make($region_area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
