<?php

namespace B2buy\Shipping\Workflow;

use B2buy\Shipping\Models\Region;
use Validator;

class RegionValidator
{

    /**
     * Determine if the given region is valid for complete status.
     *
     * @param Region $region
     *
     * @return bool / Validator
     */
    public function complete(Region $region)
    {
        return Validator::make($region->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given region is valid for verify status.
     *
     * @param Region $region
     *
     * @return bool / Validator
     */
    public function verify(Region $region)
    {
        return Validator::make($region->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given region is valid for approve status.
     *
     * @param Region $region
     *
     * @return bool / Validator
     */
    public function approve(Region $region)
    {
        return Validator::make($region->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given region is valid for publish status.
     *
     * @param Region $region
     *
     * @return bool / Validator
     */
    public function publish(Region $region)
    {
        return Validator::make($region->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given region is valid for archive status.
     *
     * @param Region $region
     *
     * @return bool / Validator
     */
    public function archive(Region $region)
    {
        return Validator::make($region->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given region is valid for unpublish status.
     *
     * @param Region $region
     *
     * @return bool / Validator
     */
    public function unpublish(Region $region)
    {
        return Validator::make($region->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
