<?php

namespace B2buy\Shipping\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Shipping\Models\Shipping;

class ShippingAction
{
    /**
     * Perform the complete action.
     *
     * @param Shipping $shipping
     *
     * @return Shipping
     */
    public function complete(Shipping $shipping)
    {
        try {
            $shipping->status = 'complete';
            return $shipping->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Shipping $shipping
     *
     * @return Shipping
     */public function verify(Shipping $shipping)
    {
        try {
            $shipping->status = 'verify';
            return $shipping->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Shipping $shipping
     *
     * @return Shipping
     */public function approve(Shipping $shipping)
    {
        try {
            $shipping->status = 'approve';
            return $shipping->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Shipping $shipping
     *
     * @return Shipping
     */public function publish(Shipping $shipping)
    {
        try {
            $shipping->status = 'publish';
            return $shipping->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Shipping $shipping
     *
     * @return Shipping
     */
    public function archive(Shipping $shipping)
    {
        try {
            $shipping->status = 'archive';
            return $shipping->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Shipping $shipping
     *
     * @return Shipping
     */
    public function unpublish(Shipping $shipping)
    {
        try {
            $shipping->status = 'unpublish';
            return $shipping->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
