<?php

namespace B2buy\Shipping\Workflow;

use B2buy\Shipping\Models\Shipping;
use Validator;

class ShippingValidator
{

    /**
     * Determine if the given shipping is valid for complete status.
     *
     * @param Shipping $shipping
     *
     * @return bool / Validator
     */
    public function complete(Shipping $shipping)
    {
        return Validator::make($shipping->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given shipping is valid for verify status.
     *
     * @param Shipping $shipping
     *
     * @return bool / Validator
     */
    public function verify(Shipping $shipping)
    {
        return Validator::make($shipping->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given shipping is valid for approve status.
     *
     * @param Shipping $shipping
     *
     * @return bool / Validator
     */
    public function approve(Shipping $shipping)
    {
        return Validator::make($shipping->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given shipping is valid for publish status.
     *
     * @param Shipping $shipping
     *
     * @return bool / Validator
     */
    public function publish(Shipping $shipping)
    {
        return Validator::make($shipping->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given shipping is valid for archive status.
     *
     * @param Shipping $shipping
     *
     * @return bool / Validator
     */
    public function archive(Shipping $shipping)
    {
        return Validator::make($shipping->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given shipping is valid for unpublish status.
     *
     * @param Shipping $shipping
     *
     * @return bool / Validator
     */
    public function unpublish(Shipping $shipping)
    {
        return Validator::make($shipping->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
